<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Error de expresión</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation>Tema oscuro</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Modo simple</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Modo científico</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Calculadora Deepin</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>La calculadora deepin es una calculadora de escritorio fácil de usar. Soporta sumas, rectas, multiplicaciones y divisiones</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Error de expresión</translation>
    </message>
</context>
</TS>